import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

//Defining the number format in legend
const numberFormat = number =>
  	(number)  ;

//Defining the structure of the pie chart
const render = data => {
  const pieData = pie().sort(null).value(d=>d.TotalLibrarySize)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(180)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.TotalLibrarySize))
  	.on("mouseover", d => console.log(d.data.TotalLibrarySize));
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
//Defining Legend
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.TotalLibrarySize));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.TotalLibrarySize));
}

//Netflix Movies and Shows in Different Countries CSV
const csvUrl =
 'https://gist.githubusercontent.com/Sai-Bhavana-Akkineni/ea421f0bdfff25dae188870c8f0639c2/raw/09f8831718f853a1de31b4620827079e13d720d5/ICE7_Piechart';

//Loading the data and considering top 10 countries
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.TotalLibrarySize-data1.TotalLibrarySize);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});